@@ -1252,8 +1252,33 @@ class FuncOnt:
             print 'Found {0} triples in the internal ontology set.'.format(len(iOntology['N3']))
         return filelist,iOntology,_newcode
 
-    def ReadOntologyPackage(self, pkgfolder, pkgname):
-        filelist,internalOntology,_newcode = self.GetOntologyPackageFiles(pkgfolder,pkgname)
+    def GetOntologyModuleFiles(self,mdlFolder,mdlName):
+        if mdlFolder not in sys.path:
+            sys.path.append(mdlFolder)
+        modulename = mdlName
+        #print sys.path
+        #_newcode = __import__(modulename, globals(), locals(), [], 0)
+        _newcode = __import__(modulename[:-3])
+        print dir(_newcode)
+        rdfList = getattr(_newcode, 'OntologyFileList')
+        internalOntology = getattr(_newcode,'InternalOntology')
+        print 'Reading ontology: '+mdlName
+        flist = rdfList()
+        filelist = [os.path.join(mdlFolder,fn) for fn in flist]
+        if len(filelist)>0:
+            print 'Files: '+', '.join(filelist)
+        else:
+            print 'No files found.'
+        iOntology = internalOntology()
+        if 'N3' in iOntology.keys():
+            print 'Found {0} triples in the internal ontology set.'.format(len(iOntology['N3']))
+        return filelist,iOntology,_newcode
+
+    def ReadOntologyPackageOrModule(self, pkgfolder, pkgname):
+        if os.path.isfile(os.path.join(pkgfolder,pkgname)) and '.py' in pkgname[-3:]:
+            filelist, internalOntology, _newcode = self.GetOntologyModuleFiles(pkgfolder, pkgname)
+        else:
+            filelist,internalOntology,_newcode = self.GetOntologyPackageFiles(pkgfolder,pkgname)
         for f in filelist:
             print f
             if f[-3:].tolower() =='rdf':
@@ -1262,15 +1287,17 @@ class FuncOnt:
                 self.ReadN3ERDC(f)
         if internalOntology is not None:
             for ns in internalOntology['Namespace'].keys():
-                ont.AddNamespace(ns,internalOntology['Namespace'][ns])
+                self.AddNamespace(ns,internalOntology['Namespace'][ns])
             for s,p,o in internalOntology['N3']:
-                ont.AddTriple(s,p,o)
+                self.AddTriple(s,p,o)
                 if 'fo:PrimaryCode' in p:
-                    s_node=ont.GetBON(s)
+                    s_node=self.GetBON(s)
                     s_node.PrimaryCode=getattr(_newcode,o)
         return _newcode
 
 
+
+
     def ReadN3ERDC(self,filename):
         isNamespace = False
         with open(filename,'r') as fp:
